import { Component, EventEmitter, Output } from '@angular/core';
import { CommonNzModule } from '../../../../../common.nz.module';
import { hazardLevelOptions, hazardStatusOptions, SearchParams } from '../../hazard.utils';

@Component({
  selector: 'hazard-search',
  standalone: true,
  imports: [CommonNzModule],
  templateUrl: './hazard-search.component.html',
  styleUrl: './hazard-search.component.less',
})
export class HazardSearchComponent {
  @Output() onChange = new EventEmitter<SearchParams>();
  state: SearchParams = {
    status: -1,
    level: '',
    onlyMine: false,
  };
  statusOptions = [{ value: -1, label: '全部状态' }, ...hazardStatusOptions];
  levelOptions = [{ value: '', label: '隐患等级' }, ...hazardLevelOptions];

  handleStatusChange(s: number) {
    this.state.status = s;
    this.onChange.emit(this.state);
  }
  handleLevelChange(l: string) {
    this.state.level = l;
    this.onChange.emit(this.state);
  }
  handleParamsChange() {
    this.onChange.emit(this.state);
  }
  get statusText() {
    return this.statusOptions.find(op => op.value === this.state.status)?.label || '全部状态';
  }
  get levelText() {
    return this.levelOptions.find(op => op.value === this.state.level)?.label || '隐患等级';
  }
}
