import { Component, Input } from '@angular/core';
import dayjs from 'dayjs';
import { CommonNzModule } from '../../../../../common.nz.module';
import { BasicDataService } from '../../../../../services/basic.service';
import { getHazardPlanStatusText, getHazardPlanTypeText } from '../inspection-plan.utils';

@Component({
  selector: 'plan-card',
  standalone: true,
  imports: [CommonNzModule],
  templateUrl: './plan-card.component.html',
  styleUrl: './plan-card.component.less',
})
export class PlanCardComponent {
  @Input() data!: Hazard.Plan;
  constructor(private basic: BasicDataService) {
    basic.init().then(() => {
      this.setInfoValues();
    });
  }
  ngOnInit() {
    this.setInfoValues();
  }
  infos = [
    { label: '排查周期', value: '' },
    { label: '排查时间', value: '' },
    { label: '发布时间', value: '' },
    { label: '发布部门', value: '' },
  ];
  setInfoValues() {
    const [du, time, createTime, d] = this.infos;
    du.value = '周循环计划 每周1次';
    time.value = `${dayjs(this.data.startDate).format('YYYY/MM/DD')}-${dayjs(this.data.endDate).format('YYYY/MM/DD')}`;
    createTime.value = dayjs(this.data.createDate).format('YYYY/MM/DD');
    d.value = this.basic.getDepartmentName(this.data.department);
  }
  get typeText() {
    return getHazardPlanTypeText(this.data.type);
  }
  get statusText() {
    return getHazardPlanStatusText(this.data.status);
  }
}
